import {Resource} from './core';

export type MessageBody = string | string[] | (string | string[])[];

export interface LanguageStatusMessageMap {
	unableToInitializeResourceDataSource(resource: Resource): string;
	unableToFetchResourceCollection(resource: Resource): string;
	unableToFetchResource(resource: Resource): string;
	languageNotAcceptable(): string;
	encodingNotAcceptable(): string;
	mediaTypeNotAcceptable(): string;
	methodNotAllowed(): string;
	urlNotFound(): string;
	badRequest(): string;
	ok(): string;
	resourceCollectionFetched(resource: Resource): string;
	resourceFetched(resource: Resource): string;
	resourceNotFound(resource: Resource): string;
	deleteNonExistingResource(resource: Resource): string;
	unableToGenerateIdFromResourceDataSource(resource: Resource): string;
	unableToEmplaceResource(resource: Resource): string;
	unableToSerializeResponse(): string;
	unableToEncodeResponse(): string;
	unableToDeleteResource(resource: Resource): string;
	resourceDeleted(resource: Resource): string;
	unableToDeserializeRequest(): string;
	patchNonExistingResource(resource: Resource): string;
	unableToPatchResource(resource: Resource): string;
	invalidResourcePatch(resource: Resource): string;
	invalidResource(resource: Resource): string;
	resourcePatched(resource: Resource): string;
	resourceCreated(resource: Resource): string;
	resourceReplaced(resource: Resource): string;
}

export interface Language {
	name: string,
	statusMessages: LanguageStatusMessageMap,
	bodies: {
		languageNotAcceptable(): MessageBody;
		encodingNotAcceptable(): MessageBody;
		mediaTypeNotAcceptable(): MessageBody;
	}
}
