import {Resource} from '../../core';
import {Language} from '../../common';

export const statusMessages = {
	unableToSerializeResponse(): string {
		return 'Unable To Serialize Response';
	},
	unableToEncodeResponse(): string {
		return 'Unable To Encode Response';
	},
	unableToInitializeResourceDataSource(resource: Resource): string {
		return `Unable To Initialize ${resource.state.itemName} Data Source`;
	},
	unableToFetchResourceCollection(resource: Resource): string {
		return `Unable To Fetch ${resource.state.itemName} Collection`;
	},
	unableToFetchResource(resource: Resource): string {
		return `Unable To Fetch ${resource.state.itemName}`;
	},
	unableToDeleteResource(resource: Resource): string {
		return `Unable To Delete ${resource.state.itemName}`;
	},
	languageNotAcceptable(): string {
		return 'Language Not Acceptable';
	},
	encodingNotAcceptable(): string {
		return 'Encoding Not Acceptable';
	},
	mediaTypeNotAcceptable(): string {
		return 'Media Type Not Acceptable';
	},
	methodNotAllowed(): string {
		return 'Method Not Allowed';
	},
	urlNotFound(): string {
		return 'URL Not Found';
	},
	badRequest(): string {
		return 'Bad Request';
	},
	ok(): string {
		return 'OK';
	},
	resourceCollectionFetched(resource: Resource): string {
		return `${resource.state.itemName} Collection Fetched`;
	},
	resourceFetched(resource: Resource): string {
		return `${resource.state.itemName} Fetched`;
	},
	resourceNotFound(resource: Resource): string {
		return `${resource.state.itemName} Not Found`;
	},
	deleteNonExistingResource(resource: Resource): string {
		return `Delete Non-Existing ${resource.state.itemName}`;
	},
	resourceDeleted(resource: Resource): string {
		return `${resource.state.itemName} Deleted`;
	},
	unableToDeserializeRequest(): string {
		return 'Unable To Deserialize Request';
	},
	patchNonExistingResource(resource: Resource): string {
		return `Patch Non-Existing ${resource.state.itemName}`;
	},
	unableToPatchResource(resource: Resource): string {
		return `Unable To Patch ${resource.state.itemName}`;
	},
	invalidResourcePatch(resource: Resource): string {
		return `Invalid ${resource.state.itemName} Patch`;
	},
	invalidResource(resource: Resource): string {
		return `Invalid ${resource.state.itemName}`;
	},
	resourcePatched(resource: Resource): string {
		return `${resource.state.itemName} Patched`;
	},
	resourceCreated(resource: Resource): string {
		return `${resource.state.itemName} Created`;
	},
	resourceReplaced(resource: Resource): string {
		return `${resource.state.itemName} Replaced`;
	},
	unableToGenerateIdFromResourceDataSource(resource: Resource): string {
		return `Unable To Generate ID From ${resource.state.itemName} Data Source`;
	},
	unableToEmplaceResource(resource: Resource): string {
		return `Unable To Emplace ${resource.state.itemName}`;
	}
} satisfies Language['statusMessages'];

export const bodies = {
	languageNotAcceptable() {
		return [];
	},
	encodingNotAcceptable() {
		return [];
	},
	mediaTypeNotAcceptable() {
		return []
	}
} satisfies Language['bodies'];

export const name = 'en' as const;
